@@ -301,8 +301,11 @@ def chose_function_loop(synced_elt: SyncedElement) -> None:
 
 
 def main(*args):
+    print("This is seafile_nautilus version", __version__)
+    print()
     # 'main' can be called from nautilus (args are retrieved from environment variable)
     if nautilus_files := _nautilus_selected_files():
+        print("I was called from Nautilus")
         if len(nautilus_files) > 1:
             Zenity.warning(_("Error"),
                            _("You must select <b>exactly one</b> file or folder."))
