@@ -231,19 +231,22 @@ class RemoteLibrary:
                             data={"permissions": permissions}).json()
 
 
-@dataclass()
 class LocalLibrary:
-    id: str = ""
-    download_head: str = ""
-    token: str = ""
-    email: str = ""
-    relay_address: str = ""
-    relay_port: str = ""
-    server_url: str = ""
-    worktree: str = ""
-    sync_worktree_name: str = ""
-    remote_head: str = ""
-    local_head: str = ""
+    def __init__(self, id: str = "", download_head: str = "", token: str = "", email: str = "",
+                 relay_address: str = "", relay_port: str = "", server_url: str = "", worktree: str = "",
+                 sync_worktree_name: str = "", remote_head: str = "",
+                 local_head: str = "", **kwargs):
+        self.id = id
+        self.worktree = worktree
+        self.local_head = local_head
+        self.remote_head = remote_head
+        self.sync_worktree_name = sync_worktree_name
+        self.server_url = server_url
+        self.relay_port = relay_port
+        self.relay_address = relay_address
+        self.email = email
+        self.token = token
+        self.download_head = download_head
 
     def __hash__(self):
         return hash('LocalLibrary' + self.id)
